﻿////////////////////////////////////////////////////////////////////////////////
// DEXiEval: A console application for evaluating decision alternatives,
//           using DEXi.NET library (http://kt.ijs.si/MarkoBohanec/dexinet.html)
//
//           Author: Marko Bohanec
//           Version: 1.0
//
//
//DEXiEval is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This software is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////
//Version 1.0 2017-03-20:
//      Ported to C# from java, JDEXi version 3.1
////////////////////////////////////////////////////////////////////////////////
using System;
using System.Collections.Generic;
using System.Text;
using DEXi;

namespace DEXiEval {

    class DEXiEval {

        static int Main(string[] args) {
		    if (args.Length != 2) {
			    Console.WriteLine("DEXiEval (.NET): Invalid input arguments");
			    Console.WriteLine("Usage: DEXiEval file_name variables");
			    Console.WriteLine("Variables should contain a \";\"-separated list of name=value pairs");
			    return 1;
		    }

		    string modelFile = args[0];
		    string variables = args[1];
		
		    Console.WriteLine("DEXi.Eval (.NET): " + modelFile + " " + variables);

		    try {
			    Model model = new Model(modelFile);
			    Console.WriteLine("\nAttributes:");
			    Console.WriteLine("  Basic: " + model.AttributesToString(model.Basic));
			    Console.WriteLine("  Aggregate: " + model.AttributesToString(model.Aggregate));
			    Console.WriteLine("  Linked: " + model.AttributesToString(model.Linked));

			    Console.WriteLine("\nDEXi evaluation results:");
			    model.ClearInputValues();
			    model.SetInputValuesByNames(variables);
			    model.Evaluate(Model.Evaluation.SET, true);
			    Console.WriteLine("Output values: " + model.OutputValues);
                return 0;
		    } catch (Exception e) {
			    Console.WriteLine("Exception: " + e.Message);
                return 0;
            }
	    }
    }
}
